# Contribution Guidelines
Thank you for your interest in contributing to my project. Whether it's a bug report, new feature, fix or additional documentation, your feedback and contributions are very important.

Please read this document before submitting any issues or pull requests to ensure that I have all the information I need to effectively respond to your bug report or contribution.

# Reporting Bugs/Feature Requests

When filing an issue, check recently opened or closed issues to ensure that someone else has not already reported the issue. Try to include as much information as possible. Details like these are incredibly helpful:

* A reproducible test case or series of steps
* The version of our code being used
* Any modifications you made relevant to the bug
* Anything unusual about your environment or deployment
